@@ -453,7 +453,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                     }
                                     that.getApplicationRoot().remove(iframe);
                                     if (btCfg.closeAfterDownload) {
-                                        that.fireDataEvent('actionResponse', { action: 'close' });
+                                        that.fireDataEvent('actionResponse', { action: 'cancel' });
                                     }
                                 });
                                 iframe.setSource(url);
